import type { Paginator } from "@smithy/types";
import { ListSecretVersionIdsCommandInput, ListSecretVersionIdsCommandOutput } from "../commands/ListSecretVersionIdsCommand";
import { SecretsManagerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListSecretVersionIds: (config: SecretsManagerPaginationConfiguration, input: ListSecretVersionIdsCommandInput, ...rest: any[]) => Paginator<ListSecretVersionIdsCommandOutput>;
