import { PaginationConfiguration } from "@smithy/types";
import { SecretsManagerClient } from "../SecretsManagerClient";
export interface SecretsManagerPaginationConfiguration
  extends PaginationConfiguration {
  client: SecretsManagerClient;
}
