import { TypeRegistry } from "@smithy/core/schema";
import {
  StaticErrorSchema,
  StaticOperationSchema,
  StaticStructureSchema,
} from "@smithy/types";
export declare var SecretsManagerServiceException$: StaticErrorSchema;
export declare var DecryptionFailure$: StaticErrorSchema;
export declare var EncryptionFailure$: StaticErrorSchema;
export declare var InternalServiceError$: StaticErrorSchema;
export declare var InvalidNextTokenException$: StaticErrorSchema;
export declare var InvalidParameterException$: StaticErrorSchema;
export declare var InvalidRequestException$: StaticErrorSchema;
export declare var LimitExceededException$: StaticErrorSchema;
export declare var MalformedPolicyDocumentException$: StaticErrorSchema;
export declare var PreconditionNotMetException$: StaticErrorSchema;
export declare var PublicPolicyException$: StaticErrorSchema;
export declare var ResourceExistsException$: StaticErrorSchema;
export declare var ResourceNotFoundException$: StaticErrorSchema;
export declare const errorTypeRegistries: TypeRegistry[];
export declare var APIErrorType$: StaticStructureSchema;
export declare var BatchGetSecretValueRequest$: StaticStructureSchema;
export declare var BatchGetSecretValueResponse$: StaticStructureSchema;
export declare var CancelRotateSecretRequest$: StaticStructureSchema;
export declare var CancelRotateSecretResponse$: StaticStructureSchema;
export declare var CreateSecretRequest$: StaticStructureSchema;
export declare var CreateSecretResponse$: StaticStructureSchema;
export declare var DeleteResourcePolicyRequest$: StaticStructureSchema;
export declare var DeleteResourcePolicyResponse$: StaticStructureSchema;
export declare var DeleteSecretRequest$: StaticStructureSchema;
export declare var DeleteSecretResponse$: StaticStructureSchema;
export declare var DescribeSecretRequest$: StaticStructureSchema;
export declare var DescribeSecretResponse$: StaticStructureSchema;
export declare var ExternalSecretRotationMetadataItem$: StaticStructureSchema;
export declare var Filter$: StaticStructureSchema;
export declare var GetRandomPasswordRequest$: StaticStructureSchema;
export declare var GetRandomPasswordResponse$: StaticStructureSchema;
export declare var GetResourcePolicyRequest$: StaticStructureSchema;
export declare var GetResourcePolicyResponse$: StaticStructureSchema;
export declare var GetSecretValueRequest$: StaticStructureSchema;
export declare var GetSecretValueResponse$: StaticStructureSchema;
export declare var ListSecretsRequest$: StaticStructureSchema;
export declare var ListSecretsResponse$: StaticStructureSchema;
export declare var ListSecretVersionIdsRequest$: StaticStructureSchema;
export declare var ListSecretVersionIdsResponse$: StaticStructureSchema;
export declare var PutResourcePolicyRequest$: StaticStructureSchema;
export declare var PutResourcePolicyResponse$: StaticStructureSchema;
export declare var PutSecretValueRequest$: StaticStructureSchema;
export declare var PutSecretValueResponse$: StaticStructureSchema;
export declare var RemoveRegionsFromReplicationRequest$: StaticStructureSchema;
export declare var RemoveRegionsFromReplicationResponse$: StaticStructureSchema;
export declare var ReplicaRegionType$: StaticStructureSchema;
export declare var ReplicateSecretToRegionsRequest$: StaticStructureSchema;
export declare var ReplicateSecretToRegionsResponse$: StaticStructureSchema;
export declare var ReplicationStatusType$: StaticStructureSchema;
export declare var RestoreSecretRequest$: StaticStructureSchema;
export declare var RestoreSecretResponse$: StaticStructureSchema;
export declare var RotateSecretRequest$: StaticStructureSchema;
export declare var RotateSecretResponse$: StaticStructureSchema;
export declare var RotationRulesType$: StaticStructureSchema;
export declare var SecretListEntry$: StaticStructureSchema;
export declare var SecretValueEntry$: StaticStructureSchema;
export declare var SecretVersionsListEntry$: StaticStructureSchema;
export declare var StopReplicationToReplicaRequest$: StaticStructureSchema;
export declare var StopReplicationToReplicaResponse$: StaticStructureSchema;
export declare var Tag$: StaticStructureSchema;
export declare var TagResourceRequest$: StaticStructureSchema;
export declare var UntagResourceRequest$: StaticStructureSchema;
export declare var UpdateSecretRequest$: StaticStructureSchema;
export declare var UpdateSecretResponse$: StaticStructureSchema;
export declare var UpdateSecretVersionStageRequest$: StaticStructureSchema;
export declare var UpdateSecretVersionStageResponse$: StaticStructureSchema;
export declare var ValidateResourcePolicyRequest$: StaticStructureSchema;
export declare var ValidateResourcePolicyResponse$: StaticStructureSchema;
export declare var ValidationErrorsEntry$: StaticStructureSchema;
export declare var BatchGetSecretValue$: StaticOperationSchema;
export declare var CancelRotateSecret$: StaticOperationSchema;
export declare var CreateSecret$: StaticOperationSchema;
export declare var DeleteResourcePolicy$: StaticOperationSchema;
export declare var DeleteSecret$: StaticOperationSchema;
export declare var DescribeSecret$: StaticOperationSchema;
export declare var GetRandomPassword$: StaticOperationSchema;
export declare var GetResourcePolicy$: StaticOperationSchema;
export declare var GetSecretValue$: StaticOperationSchema;
export declare var ListSecrets$: StaticOperationSchema;
export declare var ListSecretVersionIds$: StaticOperationSchema;
export declare var PutResourcePolicy$: StaticOperationSchema;
export declare var PutSecretValue$: StaticOperationSchema;
export declare var RemoveRegionsFromReplication$: StaticOperationSchema;
export declare var ReplicateSecretToRegions$: StaticOperationSchema;
export declare var RestoreSecret$: StaticOperationSchema;
export declare var RotateSecret$: StaticOperationSchema;
export declare var StopReplicationToReplica$: StaticOperationSchema;
export declare var TagResource$: StaticOperationSchema;
export declare var UntagResource$: StaticOperationSchema;
export declare var UpdateSecret$: StaticOperationSchema;
export declare var UpdateSecretVersionStage$: StaticOperationSchema;
export declare var ValidateResourcePolicy$: StaticOperationSchema;
