import { Paginator } from "@smithy/types";
import {
  BatchGetSecretValueCommandInput,
  BatchGetSecretValueCommandOutput,
} from "../commands/BatchGetSecretValueCommand";
import { SecretsManagerPaginationConfiguration } from "./Interfaces";
export declare const paginateBatchGetSecretValue: (
  config: SecretsManagerPaginationConfiguration,
  input: BatchGetSecretValueCommandInput,
  ...rest: any[]
) => Paginator<BatchGetSecretValueCommandOutput>;
