import { Paginator } from "@smithy/types";
import {
  ListSecretVersionIdsCommandInput,
  ListSecretVersionIdsCommandOutput,
} from "../commands/ListSecretVersionIdsCommand";
import { SecretsManagerPaginationConfiguration } from "./Interfaces";
export declare const paginateListSecretVersionIds: (
  config: SecretsManagerPaginationConfiguration,
  input: ListSecretVersionIdsCommandInput,
  ...rest: any[]
) => Paginator<ListSecretVersionIdsCommandOutput>;
