const _AAD = "AutomaticallyAfterDays";
const _APIELT = "APIErrorListType";
const _APIET = "APIErrorType";
const _ARN = "ARN";
const _ARR = "AddReplicaRegions";
const _ARRLT = "AddReplicaRegionListType";
const _BGSV = "BatchGetSecretValue";
const _BGSVR = "BatchGetSecretValueRequest";
const _BGSVRa = "BatchGetSecretValueResponse";
const _BPP = "BlockPublicPolicy";
const _CD = "CreatedDate";
const _CN = "CheckName";
const _CRS = "CancelRotateSecret";
const _CRSR = "CancelRotateSecretRequest";
const _CRSRa = "CancelRotateSecretResponse";
const _CRT = "ClientRequestToken";
const _CS = "CreateSecret";
const _CSR = "CreateSecretRequest";
const _CSRr = "CreateSecretResponse";
const _D = "Description";
const _DD = "DeletionDate";
const _DDe = "DeletedDate";
const _DF = "DecryptionFailure";
const _DRP = "DeleteResourcePolicy";
const _DRPR = "DeleteResourcePolicyRequest";
const _DRPRe = "DeleteResourcePolicyResponse";
const _DS = "DeleteSecret";
const _DSR = "DeleteSecretRequest";
const _DSRe = "DeleteSecretResponse";
const _DSRes = "DescribeSecretRequest";
const _DSResc = "DescribeSecretResponse";
const _DSe = "DescribeSecret";
const _Du = "Duration";
const _E = "Errors";
const _EC = "ErrorCode";
const _ECx = "ExcludeCharacters";
const _EF = "EncryptionFailure";
const _EL = "ExcludeLowercase";
const _EM = "ErrorMessage";
const _EN = "ExcludeNumbers";
const _EP = "ExcludePunctuation";
const _ESRM = "ExternalSecretRotationMetadata";
const _ESRMI = "ExternalSecretRotationMetadataItem";
const _ESRMT = "ExternalSecretRotationMetadataType";
const _ESRRA = "ExternalSecretRotationRoleArn";
const _EU = "ExcludeUppercase";
const _F = "Filters";
const _FDWR = "ForceDeleteWithoutRecovery";
const _FLT = "FiltersListType";
const _FORS = "ForceOverwriteReplicaSecret";
const _Fi = "Filter";
const _GRP = "GetRandomPassword";
const _GRPR = "GetRandomPasswordRequest";
const _GRPRe = "GetRandomPasswordResponse";
const _GRPRet = "GetResourcePolicyRequest";
const _GRPRete = "GetResourcePolicyResponse";
const _GRPe = "GetResourcePolicy";
const _GSV = "GetSecretValue";
const _GSVR = "GetSecretValueRequest";
const _GSVRe = "GetSecretValueResponse";
const _ID = "IncludeDeprecated";
const _INTE = "InvalidNextTokenException";
const _IPD = "IncludePlannedDeletion";
const _IPE = "InvalidParameterException";
const _IRE = "InvalidRequestException";
const _IS = "IncludeSpace";
const _ISE = "InternalServiceError";
const _K = "Key";
const _KKI = "KmsKeyId";
const _KKIm = "KmsKeyIds";
const _LAD = "LastAccessedDate";
const _LCD = "LastChangedDate";
const _LEE = "LimitExceededException";
const _LRD = "LastRotatedDate";
const _LS = "ListSecrets";
const _LSR = "ListSecretsRequest";
const _LSRi = "ListSecretsResponse";
const _LSVI = "ListSecretVersionIds";
const _LSVIR = "ListSecretVersionIdsRequest";
const _LSVIRi = "ListSecretVersionIdsResponse";
const _M = "Message";
const _MPDE = "MalformedPolicyDocumentException";
const _MR = "MaxResults";
const _MTVI = "MoveToVersionId";
const _N = "Name";
const _NRD = "NextRotationDate";
const _NT = "NextToken";
const _OS = "OwningService";
const _PL = "PasswordLength";
const _PNME = "PreconditionNotMetException";
const _PPE = "PublicPolicyException";
const _PR = "PrimaryRegion";
const _PRP = "PutResourcePolicy";
const _PRPR = "PutResourcePolicyRequest";
const _PRPRu = "PutResourcePolicyResponse";
const _PSV = "PutSecretValue";
const _PSVR = "PutSecretValueRequest";
const _PSVRu = "PutSecretValueResponse";
const _PVP = "PolicyValidationPassed";
const _R = "Region";
const _RE = "RotationEnabled";
const _REE = "ResourceExistsException";
const _REIT = "RequireEachIncludedType";
const _RFVI = "RemoveFromVersionId";
const _RI = "RotateImmediately";
const _RLARN = "RotationLambdaARN";
const _RNFE = "ResourceNotFoundException";
const _RP = "RandomPassword";
const _RPT = "RandomPasswordType";
const _RPe = "ResourcePolicy";
const _RR = "RotationRules";
const _RRFR = "RemoveRegionsFromReplication";
const _RRFRR = "RemoveRegionsFromReplicationRequest";
const _RRFRRe = "RemoveRegionsFromReplicationResponse";
const _RRR = "RemoveReplicaRegions";
const _RRT = "ReplicaRegionType";
const _RRTo = "RotationRulesType";
const _RS = "ReplicationStatus";
const _RSLT = "ReplicationStatusListType";
const _RSR = "RestoreSecretRequest";
const _RSRe = "RestoreSecretResponse";
const _RSRo = "RotateSecretRequest";
const _RSRot = "RotateSecretResponse";
const _RST = "ReplicationStatusType";
const _RSTR = "ReplicateSecretToRegions";
const _RSTRR = "ReplicateSecretToRegionsRequest";
const _RSTRRe = "ReplicateSecretToRegionsResponse";
const _RSe = "RestoreSecret";
const _RSo = "RotateSecret";
const _RT = "RotationToken";
const _RTT = "RotationTokenType";
const _RWID = "RecoveryWindowInDays";
const _S = "Status";
const _SB = "SecretBinary";
const _SBT = "SecretBinaryType";
const _SBo = "SortBy";
const _SE = "ScheduleExpression";
const _SI = "SecretId";
const _SIL = "SecretIdList";
const _SL = "SecretList";
const _SLE = "SecretListEntry";
const _SLT = "SecretListType";
const _SM = "StatusMessage";
const _SO = "SortOrder";
const _SRTR = "StopReplicationToReplica";
const _SRTRR = "StopReplicationToReplicaRequest";
const _SRTRRt = "StopReplicationToReplicaResponse";
const _SS = "SecretString";
const _SST = "SecretStringType";
const _SV = "SecretValues";
const _SVE = "SecretValueEntry";
const _SVLE = "SecretVersionsListEntry";
const _SVLT = "SecretVersionsListType";
const _SVT = "SecretValuesType";
const _SVTS = "SecretVersionsToStages";
const _SVTSMT = "SecretVersionsToStagesMapType";
const _T = "Tags";
const _TK = "TagKeys";
const _TLT = "TagListType";
const _TR = "TagResource";
const _TRR = "TagResourceRequest";
const _Ta = "Tag";
const _Ty = "Type";
const _UR = "UntagResource";
const _URR = "UntagResourceRequest";
const _US = "UpdateSecret";
const _USR = "UpdateSecretRequest";
const _USRp = "UpdateSecretResponse";
const _USVS = "UpdateSecretVersionStage";
const _USVSR = "UpdateSecretVersionStageRequest";
const _USVSRp = "UpdateSecretVersionStageResponse";
const _V = "Value";
const _VE = "ValidationErrors";
const _VEE = "ValidationErrorsEntry";
const _VET = "ValidationErrorsType";
const _VI = "VersionId";
const _VITS = "VersionIdsToStages";
const _VRP = "ValidateResourcePolicy";
const _VRPR = "ValidateResourcePolicyRequest";
const _VRPRa = "ValidateResourcePolicyResponse";
const _VS = "VersionStage";
const _VSe = "VersionStages";
const _Va = "Values";
const _Ve = "Versions";
const _c = "client";
const _e = "error";
const _s = "smithy.ts.sdk.synthetic.com.amazonaws.secretsmanager";
const _se = "server";
const n0 = "com.amazonaws.secretsmanager";
import { TypeRegistry } from "@smithy/core/schema";
import { DecryptionFailure, EncryptionFailure, InternalServiceError, InvalidNextTokenException, InvalidParameterException, InvalidRequestException, LimitExceededException, MalformedPolicyDocumentException, PreconditionNotMetException, PublicPolicyException, ResourceExistsException, ResourceNotFoundException, } from "../models/errors";
import { SecretsManagerServiceException } from "../models/SecretsManagerServiceException";
const _s_registry = TypeRegistry.for(_s);
export var SecretsManagerServiceException$ = [-3, _s, "SecretsManagerServiceException", 0, [], []];
_s_registry.registerError(SecretsManagerServiceException$, SecretsManagerServiceException);
const n0_registry = TypeRegistry.for(n0);
export var DecryptionFailure$ = [-3, n0, _DF,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(DecryptionFailure$, DecryptionFailure);
export var EncryptionFailure$ = [-3, n0, _EF,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(EncryptionFailure$, EncryptionFailure);
export var InternalServiceError$ = [-3, n0, _ISE,
    { [_e]: _se },
    [_M],
    [0]
];
n0_registry.registerError(InternalServiceError$, InternalServiceError);
export var InvalidNextTokenException$ = [-3, n0, _INTE,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(InvalidNextTokenException$, InvalidNextTokenException);
export var InvalidParameterException$ = [-3, n0, _IPE,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(InvalidParameterException$, InvalidParameterException);
export var InvalidRequestException$ = [-3, n0, _IRE,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(InvalidRequestException$, InvalidRequestException);
export var LimitExceededException$ = [-3, n0, _LEE,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(LimitExceededException$, LimitExceededException);
export var MalformedPolicyDocumentException$ = [-3, n0, _MPDE,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(MalformedPolicyDocumentException$, MalformedPolicyDocumentException);
export var PreconditionNotMetException$ = [-3, n0, _PNME,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(PreconditionNotMetException$, PreconditionNotMetException);
export var PublicPolicyException$ = [-3, n0, _PPE,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(PublicPolicyException$, PublicPolicyException);
export var ResourceExistsException$ = [-3, n0, _REE,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(ResourceExistsException$, ResourceExistsException);
export var ResourceNotFoundException$ = [-3, n0, _RNFE,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(ResourceNotFoundException$, ResourceNotFoundException);
export const errorTypeRegistries = [
    _s_registry,
    n0_registry,
];
var RandomPasswordType = [0, n0, _RPT, 8, 0];
var RotationTokenType = [0, n0, _RTT, 8, 0];
var SecretBinaryType = [0, n0, _SBT, 8, 21];
var SecretStringType = [0, n0, _SST, 8, 0];
export var APIErrorType$ = [3, n0, _APIET,
    0,
    [_SI, _EC, _M],
    [0, 0, 0]
];
export var BatchGetSecretValueRequest$ = [3, n0, _BGSVR,
    0,
    [_SIL, _F, _MR, _NT],
    [64 | 0, () => FiltersListType, 1, 0]
];
export var BatchGetSecretValueResponse$ = [3, n0, _BGSVRa,
    0,
    [_SV, _NT, _E],
    [[() => SecretValuesType, 0], 0, () => APIErrorListType]
];
export var CancelRotateSecretRequest$ = [3, n0, _CRSR,
    0,
    [_SI],
    [0], 1
];
export var CancelRotateSecretResponse$ = [3, n0, _CRSRa,
    0,
    [_ARN, _N, _VI],
    [0, 0, 0]
];
export var CreateSecretRequest$ = [3, n0, _CSR,
    0,
    [_N, _CRT, _D, _KKI, _SB, _SS, _T, _ARR, _FORS, _Ty],
    [0, [0, 4], 0, 0, [() => SecretBinaryType, 0], [() => SecretStringType, 0], () => TagListType, () => AddReplicaRegionListType, 2, 0], 1
];
export var CreateSecretResponse$ = [3, n0, _CSRr,
    0,
    [_ARN, _N, _VI, _RS],
    [0, 0, 0, () => ReplicationStatusListType]
];
export var DeleteResourcePolicyRequest$ = [3, n0, _DRPR,
    0,
    [_SI],
    [0], 1
];
export var DeleteResourcePolicyResponse$ = [3, n0, _DRPRe,
    0,
    [_ARN, _N],
    [0, 0]
];
export var DeleteSecretRequest$ = [3, n0, _DSR,
    0,
    [_SI, _RWID, _FDWR],
    [0, 1, 2], 1
];
export var DeleteSecretResponse$ = [3, n0, _DSRe,
    0,
    [_ARN, _N, _DD],
    [0, 0, 4]
];
export var DescribeSecretRequest$ = [3, n0, _DSRes,
    0,
    [_SI],
    [0], 1
];
export var DescribeSecretResponse$ = [3, n0, _DSResc,
    0,
    [_ARN, _N, _Ty, _D, _KKI, _RE, _RLARN, _RR, _ESRM, _ESRRA, _LRD, _LCD, _LAD, _DDe, _NRD, _T, _VITS, _OS, _CD, _PR, _RS],
    [0, 0, 0, 0, 0, 2, 0, () => RotationRulesType$, () => ExternalSecretRotationMetadataType, 0, 4, 4, 4, 4, 4, () => TagListType, [2, n0, _SVTSMT, 0, 0, 64 | 0], 0, 4, 0, () => ReplicationStatusListType]
];
export var ExternalSecretRotationMetadataItem$ = [3, n0, _ESRMI,
    0,
    [_K, _V],
    [0, 0]
];
export var Filter$ = [3, n0, _Fi,
    0,
    [_K, _Va],
    [0, 64 | 0]
];
export var GetRandomPasswordRequest$ = [3, n0, _GRPR,
    0,
    [_PL, _ECx, _EN, _EP, _EU, _EL, _IS, _REIT],
    [1, 0, 2, 2, 2, 2, 2, 2]
];
export var GetRandomPasswordResponse$ = [3, n0, _GRPRe,
    0,
    [_RP],
    [[() => RandomPasswordType, 0]]
];
export var GetResourcePolicyRequest$ = [3, n0, _GRPRet,
    0,
    [_SI],
    [0], 1
];
export var GetResourcePolicyResponse$ = [3, n0, _GRPRete,
    0,
    [_ARN, _N, _RPe],
    [0, 0, 0]
];
export var GetSecretValueRequest$ = [3, n0, _GSVR,
    0,
    [_SI, _VI, _VS],
    [0, 0, 0], 1
];
export var GetSecretValueResponse$ = [3, n0, _GSVRe,
    0,
    [_ARN, _N, _VI, _SB, _SS, _VSe, _CD],
    [0, 0, 0, [() => SecretBinaryType, 0], [() => SecretStringType, 0], 64 | 0, 4]
];
export var ListSecretsRequest$ = [3, n0, _LSR,
    0,
    [_IPD, _MR, _NT, _F, _SO, _SBo],
    [2, 1, 0, () => FiltersListType, 0, 0]
];
export var ListSecretsResponse$ = [3, n0, _LSRi,
    0,
    [_SL, _NT],
    [() => SecretListType, 0]
];
export var ListSecretVersionIdsRequest$ = [3, n0, _LSVIR,
    0,
    [_SI, _MR, _NT, _ID],
    [0, 1, 0, 2], 1
];
export var ListSecretVersionIdsResponse$ = [3, n0, _LSVIRi,
    0,
    [_Ve, _NT, _ARN, _N],
    [() => SecretVersionsListType, 0, 0, 0]
];
export var PutResourcePolicyRequest$ = [3, n0, _PRPR,
    0,
    [_SI, _RPe, _BPP],
    [0, 0, 2], 2
];
export var PutResourcePolicyResponse$ = [3, n0, _PRPRu,
    0,
    [_ARN, _N],
    [0, 0]
];
export var PutSecretValueRequest$ = [3, n0, _PSVR,
    0,
    [_SI, _CRT, _SB, _SS, _VSe, _RT],
    [0, [0, 4], [() => SecretBinaryType, 0], [() => SecretStringType, 0], 64 | 0, [() => RotationTokenType, 0]], 1
];
export var PutSecretValueResponse$ = [3, n0, _PSVRu,
    0,
    [_ARN, _N, _VI, _VSe],
    [0, 0, 0, 64 | 0]
];
export var RemoveRegionsFromReplicationRequest$ = [3, n0, _RRFRR,
    0,
    [_SI, _RRR],
    [0, 64 | 0], 2
];
export var RemoveRegionsFromReplicationResponse$ = [3, n0, _RRFRRe,
    0,
    [_ARN, _RS],
    [0, () => ReplicationStatusListType]
];
export var ReplicaRegionType$ = [3, n0, _RRT,
    0,
    [_R, _KKI],
    [0, 0]
];
export var ReplicateSecretToRegionsRequest$ = [3, n0, _RSTRR,
    0,
    [_SI, _ARR, _FORS],
    [0, () => AddReplicaRegionListType, 2], 2
];
export var ReplicateSecretToRegionsResponse$ = [3, n0, _RSTRRe,
    0,
    [_ARN, _RS],
    [0, () => ReplicationStatusListType]
];
export var ReplicationStatusType$ = [3, n0, _RST,
    0,
    [_R, _KKI, _S, _SM, _LAD],
    [0, 0, 0, 0, 4]
];
export var RestoreSecretRequest$ = [3, n0, _RSR,
    0,
    [_SI],
    [0], 1
];
export var RestoreSecretResponse$ = [3, n0, _RSRe,
    0,
    [_ARN, _N],
    [0, 0]
];
export var RotateSecretRequest$ = [3, n0, _RSRo,
    0,
    [_SI, _CRT, _RLARN, _RR, _ESRM, _ESRRA, _RI],
    [0, [0, 4], 0, () => RotationRulesType$, () => ExternalSecretRotationMetadataType, 0, 2], 1
];
export var RotateSecretResponse$ = [3, n0, _RSRot,
    0,
    [_ARN, _N, _VI],
    [0, 0, 0]
];
export var RotationRulesType$ = [3, n0, _RRTo,
    0,
    [_AAD, _Du, _SE],
    [1, 0, 0]
];
export var SecretListEntry$ = [3, n0, _SLE,
    0,
    [_ARN, _N, _Ty, _D, _KKI, _RE, _RLARN, _RR, _ESRM, _ESRRA, _LRD, _LCD, _LAD, _DDe, _NRD, _T, _SVTS, _OS, _CD, _PR],
    [0, 0, 0, 0, 0, 2, 0, () => RotationRulesType$, () => ExternalSecretRotationMetadataType, 0, 4, 4, 4, 4, 4, () => TagListType, [2, n0, _SVTSMT, 0, 0, 64 | 0], 0, 4, 0]
];
export var SecretValueEntry$ = [3, n0, _SVE,
    0,
    [_ARN, _N, _VI, _SB, _SS, _VSe, _CD],
    [0, 0, 0, [() => SecretBinaryType, 0], [() => SecretStringType, 0], 64 | 0, 4]
];
export var SecretVersionsListEntry$ = [3, n0, _SVLE,
    0,
    [_VI, _VSe, _LAD, _CD, _KKIm],
    [0, 64 | 0, 4, 4, 64 | 0]
];
export var StopReplicationToReplicaRequest$ = [3, n0, _SRTRR,
    0,
    [_SI],
    [0], 1
];
export var StopReplicationToReplicaResponse$ = [3, n0, _SRTRRt,
    0,
    [_ARN],
    [0]
];
export var Tag$ = [3, n0, _Ta,
    0,
    [_K, _V],
    [0, 0]
];
export var TagResourceRequest$ = [3, n0, _TRR,
    0,
    [_SI, _T],
    [0, () => TagListType], 2
];
export var UntagResourceRequest$ = [3, n0, _URR,
    0,
    [_SI, _TK],
    [0, 64 | 0], 2
];
export var UpdateSecretRequest$ = [3, n0, _USR,
    0,
    [_SI, _CRT, _D, _KKI, _SB, _SS, _Ty],
    [0, [0, 4], 0, 0, [() => SecretBinaryType, 0], [() => SecretStringType, 0], 0], 1
];
export var UpdateSecretResponse$ = [3, n0, _USRp,
    0,
    [_ARN, _N, _VI],
    [0, 0, 0]
];
export var UpdateSecretVersionStageRequest$ = [3, n0, _USVSR,
    0,
    [_SI, _VS, _RFVI, _MTVI],
    [0, 0, 0, 0], 2
];
export var UpdateSecretVersionStageResponse$ = [3, n0, _USVSRp,
    0,
    [_ARN, _N],
    [0, 0]
];
export var ValidateResourcePolicyRequest$ = [3, n0, _VRPR,
    0,
    [_RPe, _SI],
    [0, 0], 1
];
export var ValidateResourcePolicyResponse$ = [3, n0, _VRPRa,
    0,
    [_PVP, _VE],
    [2, () => ValidationErrorsType]
];
export var ValidationErrorsEntry$ = [3, n0, _VEE,
    0,
    [_CN, _EM],
    [0, 0]
];
var __Unit = "unit";
var AddReplicaRegionListType = [1, n0, _ARRLT,
    0, () => ReplicaRegionType$
];
var APIErrorListType = [1, n0, _APIELT,
    0, () => APIErrorType$
];
var ExternalSecretRotationMetadataType = [1, n0, _ESRMT,
    0, () => ExternalSecretRotationMetadataItem$
];
var FiltersListType = [1, n0, _FLT,
    0, () => Filter$
];
var FilterValuesStringList = 64 | 0;
var KmsKeyIdListType = 64 | 0;
var RemoveReplicaRegionListType = 64 | 0;
var ReplicationStatusListType = [1, n0, _RSLT,
    0, () => ReplicationStatusType$
];
var SecretIdListType = 64 | 0;
var SecretListType = [1, n0, _SLT,
    0, () => SecretListEntry$
];
var SecretValuesType = [1, n0, _SVT,
    0, [() => SecretValueEntry$,
        0]
];
var SecretVersionsListType = [1, n0, _SVLT,
    0, () => SecretVersionsListEntry$
];
var SecretVersionStagesType = 64 | 0;
var TagKeyListType = 64 | 0;
var TagListType = [1, n0, _TLT,
    0, () => Tag$
];
var ValidationErrorsType = [1, n0, _VET,
    0, () => ValidationErrorsEntry$
];
var SecretVersionsToStagesMapType = [2, n0, _SVTSMT,
    0, 0, 64 | 0
];
export var BatchGetSecretValue$ = [9, n0, _BGSV,
    0, () => BatchGetSecretValueRequest$, () => BatchGetSecretValueResponse$
];
export var CancelRotateSecret$ = [9, n0, _CRS,
    0, () => CancelRotateSecretRequest$, () => CancelRotateSecretResponse$
];
export var CreateSecret$ = [9, n0, _CS,
    0, () => CreateSecretRequest$, () => CreateSecretResponse$
];
export var DeleteResourcePolicy$ = [9, n0, _DRP,
    0, () => DeleteResourcePolicyRequest$, () => DeleteResourcePolicyResponse$
];
export var DeleteSecret$ = [9, n0, _DS,
    0, () => DeleteSecretRequest$, () => DeleteSecretResponse$
];
export var DescribeSecret$ = [9, n0, _DSe,
    0, () => DescribeSecretRequest$, () => DescribeSecretResponse$
];
export var GetRandomPassword$ = [9, n0, _GRP,
    0, () => GetRandomPasswordRequest$, () => GetRandomPasswordResponse$
];
export var GetResourcePolicy$ = [9, n0, _GRPe,
    0, () => GetResourcePolicyRequest$, () => GetResourcePolicyResponse$
];
export var GetSecretValue$ = [9, n0, _GSV,
    0, () => GetSecretValueRequest$, () => GetSecretValueResponse$
];
export var ListSecrets$ = [9, n0, _LS,
    0, () => ListSecretsRequest$, () => ListSecretsResponse$
];
export var ListSecretVersionIds$ = [9, n0, _LSVI,
    0, () => ListSecretVersionIdsRequest$, () => ListSecretVersionIdsResponse$
];
export var PutResourcePolicy$ = [9, n0, _PRP,
    0, () => PutResourcePolicyRequest$, () => PutResourcePolicyResponse$
];
export var PutSecretValue$ = [9, n0, _PSV,
    0, () => PutSecretValueRequest$, () => PutSecretValueResponse$
];
export var RemoveRegionsFromReplication$ = [9, n0, _RRFR,
    0, () => RemoveRegionsFromReplicationRequest$, () => RemoveRegionsFromReplicationResponse$
];
export var ReplicateSecretToRegions$ = [9, n0, _RSTR,
    0, () => ReplicateSecretToRegionsRequest$, () => ReplicateSecretToRegionsResponse$
];
export var RestoreSecret$ = [9, n0, _RSe,
    0, () => RestoreSecretRequest$, () => RestoreSecretResponse$
];
export var RotateSecret$ = [9, n0, _RSo,
    0, () => RotateSecretRequest$, () => RotateSecretResponse$
];
export var StopReplicationToReplica$ = [9, n0, _SRTR,
    0, () => StopReplicationToReplicaRequest$, () => StopReplicationToReplicaResponse$
];
export var TagResource$ = [9, n0, _TR,
    0, () => TagResourceRequest$, () => __Unit
];
export var UntagResource$ = [9, n0, _UR,
    0, () => UntagResourceRequest$, () => __Unit
];
export var UpdateSecret$ = [9, n0, _US,
    0, () => UpdateSecretRequest$, () => UpdateSecretResponse$
];
export var UpdateSecretVersionStage$ = [9, n0, _USVS,
    0, () => UpdateSecretVersionStageRequest$, () => UpdateSecretVersionStageResponse$
];
export var ValidateResourcePolicy$ = [9, n0, _VRP,
    0, () => ValidateResourcePolicyRequest$, () => ValidateResourcePolicyResponse$
];
